@@ -11,31 +11,31 @@ import os, config_path
 SECRET_KEY                                          = os.environ.get('SECRET_KEY')
 MAX_PASSWORD_LENGTH                                 = os.environ.get('MAX_PASSWORD_LENGTH')
 
-SENDGRID_API_KEY                                    = os.environ.get('SENDGRID_API_KEY')
+#SENDGRID_API_KEY                                    = os.environ.get('SENDGRID_API_KEY')
 
 
-MAILJET_API_KEY                                     = os.environ.get('MAILJET_API_KEY')
-MAILJET_SECRET_KEY                                  = os.environ.get('MAILJET_SECRET_KEY')
+#MAILJET_API_KEY                                     = os.environ.get('MAILJET_API_KEY')
+#MAILJET_SECRET_KEY                                  = os.environ.get('MAILJET_SECRET_KEY')
 
 CRYPTO_SECRET_KEY                                   = os.environ.get('CRYPTO_SECRET_KEY')
 
-BIGQUERY_GCLOUD_PROJECT_ID                          = os.environ.get('BIGQUERY_GCLOUD_PROJECT_ID')
-BIGQUERY_SERVICE_ACCOUNT_KEY_FILEPATH               = os.environ.get('BIGQUERY_SERVICE_ACCOUNT_KEY')
-BIGQUERY_SERVICE_CREDENTIAL_PATH                    = os.path.abspath(os.path.dirname(config_path.__file__)) + '/' + BIGQUERY_SERVICE_ACCOUNT_KEY_FILEPATH
-BIGQUERY_GCLOUD_LOCATION                            = os.environ.get('BIGQUERY_GCLOUD_LOCATION')
+#BIGQUERY_GCLOUD_PROJECT_ID                          = os.environ.get('BIGQUERY_GCLOUD_PROJECT_ID')
+#BIGQUERY_SERVICE_ACCOUNT_KEY_FILEPATH               = os.environ.get('BIGQUERY_SERVICE_ACCOUNT_KEY')
+#BIGQUERY_SERVICE_CREDENTIAL_PATH                    = '%s/%s' % (os.path.abspath(os.path.dirname(config_path.__file__)) , BIGQUERY_SERVICE_ACCOUNT_KEY_FILEPATH)
+#BIGQUERY_GCLOUD_LOCATION                            = os.environ.get('BIGQUERY_GCLOUD_LOCATION')
 
 #-----------------------------------------------------------------
 # Mail Server settings
 #-----------------------------------------------------------------
-MAIL_SERVER     = 'localhost'
-MAIL_PORT       = 25
-MAIL_USERNAME   = None
-MAIL_PASSWORD   = None
-MAIL_USE_TLS    = False
-MAIL_USE_SSL    = True
-MAIL_ADMINS     = ['you@example.com']
+#MAIL_SERVER     = 'localhost'
+#MAIL_PORT       = 25
+#MAIL_USERNAME   = None
+#MAIL_PASSWORD   = None
+#MAIL_USE_TLS    = False
+#MAIL_USE_SSL    = True
+#MAIL_ADMINS     = ['you@example.com']
 
-DEFAULT_SENDER = os.environ['DEFAULT_SENDER']
+#DEFAULT_SENDER = os.environ['DEFAULT_SENDER']
 
 DEFAULT_COUNTRY_CODE                                = 'my'
 DEFAULT_GMT                                         = 8
