@@ -5,9 +5,9 @@ Created on 29 Apr 2020
 '''
 import hashlib
 import logging
-from urllib.parse import urlencode, quote_plus 
+from six.moves.urllib.parse import urlencode, quote_plus
  
-logger = logging.getLogger('user_util') 
+logger = logging.getLogger('lib') 
  
 def get_gravatar_url(email):
     
@@ -16,7 +16,7 @@ def get_gravatar_url(email):
     
     email = email.encode('utf-8')
     
-    logging.debug('email=%s', email)
+    logger.debug('email=%s', email)
     # construct the url
     hashed_email = hashlib.md5(email.lower()).hexdigest()
     logger.debug('hashed_email=%s', hashed_email)
