@@ -14,13 +14,14 @@ import uuid
 
 logger = logging.getLogger('import')
 
-def create_bigquery_client(info=None, credential_filepath=None):
+def create_bigquery_client(info=None, credential_filepath=None, project_id=None):
     if info:
         cred = service_account.Credentials.from_service_account_info(info)
         
     else:
         if credential_filepath:
             cred = service_account.Credentials.from_service_account_file(credential_filepath)
+        '''
         else:
             cred = service_account.Credentials.from_service_account_file(
                                                             lib_conf.BIGQUERY_SERVICE_CREDENTIAL_PATH,
@@ -28,14 +29,18 @@ def create_bigquery_client(info=None, credential_filepath=None):
                                                                     "https://www.googleapis.com/auth/bigquery.insertdata"
                                                                     ]
                                                             )
-
+        '''
+            
     #client = bigquery.Client(project=lib_conf.BIGQUERY_GCLOUD_PROJECT_ID, credentials=cred, location=lib_conf.BIGQUERY_GCLOUD_LOCATION)
-    client = bigquery.Client(project=lib_conf.BIGQUERY_GCLOUD_PROJECT_ID, credentials=cred)
-    
-    return client 
+    #client = bigquery.Client(project=lib_conf.BIGQUERY_GCLOUD_PROJECT_ID, credentials=cred)
+    if cred:
+        client = bigquery.Client(project=project_id, credentials=cred)
+        
+        return client 
 
-def create_dataset_reference(dataset_name):
-    dataset_ref = DatasetReference(lib_conf.BIGQUERY_GCLOUD_PROJECT_ID, dataset_name)
+def create_dataset_reference(dataset_name, project_id):
+    #dataset_ref = DatasetReference(lib_conf.BIGQUERY_GCLOUD_PROJECT_ID, dataset_name)
+    dataset_ref = DatasetReference(project_id, dataset_name)
     return dataset_ref
 
 
